<CsoundSynthesizer>
<CsOptions>
-o demo.wav -W
</CsOptions>
; ==============================================
<CsInstruments>

sr	=	48000
ksmps	=	1
nchnls	=	2
0dbfs	=	1

#include "m_segk.udo"
#include "m_scene_speaker.udo"
#include "m_3d_move.udo"
#include "m_3d_obstacle.udo"
#include "m_3d_atmo.udo"
#include "m_3d_place_source.udo"
#include "m_3d_global_reverb.udo"

gasrc init 0 ; source signal for late reflections reverb
gklx init 2.5 ; listener x
gkly init 2.5 ; listener y
gklz init 1.25 ; listener z
gkheadrot init 0 ; listener head rotation/angle

instr Atmo ; Create a background atmosphere
	iroomfn init 1 ; Room ftable
	istart init 10 ; Start in seconds of second atmo copy
	isoundfn init 2 ; ftable holding atmo soundfile
	al, ar, asrc m_3d_atmo gklx, gkly, gklz, gkheadrot, isoundfn, istart, iroomfn
	gasrc += asrc
	outs al, ar
endin

instr Moving_obj ; A moving sound source
	; Create a sound source with transients
	kphs phasor 5
	kenv table (1-kphs), 5, 1, 0, 1 ; an exponential repeating curve
	asrc vco2 kenv, 165, 0

	; Set up the table numbers
	iroomfn init 1 ; Room description table (so we don't bump into the walls)
	ifn1 init 3 ; Log curve
	ifn2 init 4 ; Linear curve
	ifn3 init 5 ; Exponential curve
	imovefn init 6 ; ftable with the movement profile
	; Read a movement from ftable
	kx, ky, kz m_3d_move imovefn, ifn1, ifn2, ifn3, iroomfn

	; Now set up the obstacles ftable
	iobstaclefn init 7

	; And emulate our source moving past the obstacles
	al, ar m_3d_obstacle asrc, kx, ky, kz, gklx, gkly, gklz, gkheadrot, \
		iobstaclefn, iroomfn
	
	; Add our source to the global source
	gasrc += asrc

	; And output the two channels
	outs al, ar
endin

instr Speaker ; Put music from a speaker on the scene
	asound soundin "sound.wav" ; a bit of music

	; Set up the speaker
	isize init .2 ; 20 centimetre cube
	ilo init 120 ; Lowcut at 120Hz (bad multimedia spekaer?)
	ihi init 10000 ; Highcut at 10kHz
	irolloff init 1.5 ; 12dB/oct i.e. 2-pole filter with .5 Q
	aspeaker m_scene_speaker asound, isize, ilo, ihi, irolloff

	iroomfn init 1 ; Room descriiption function
	ix init 2 ; spekaer x
	iy init 4.5 ; speaker y
	iz init 1.6 ; speaker z
	al, ar m_3d_place_source aspeaker, ix, iy, iz, gklx, gkly, gklz, gkheadrot, \
		iroomfn
	gasrc += aspeaker ; Add speaker to reverb source
	outs al, ar ; Output speaker sound within the room (early reflections)
endin

instr Global_rev ; Global late reflections reverb
	iroomfn init 1 ; Room ftable
	al, ar m_3d_global_reverb gasrc, iroomfn
	outs al, ar
	gasrc = 0
endin

</CsInstruments>
; ==============================================
<CsScore>
f1 0 23 -23 "room.ftable"
f2 0 0 1 "atmo.wav" 0 0 0
f3 0 4096 23 "log.ftable"
f4 0 4096 7 0 4096 1
f5 0 4096 23 "exp.ftable"
f6 0 25 -23 "move.ftable"
f7 0 15 -23 "obstacle.ftable"

i"Atmo" 0 45
i"Moving_obj" 5 25
i"Speaker" 28 11
i"Global_rev" 0 50
e
</CsScore>
</CsoundSynthesizer>
