/*
m_scene_blender - Read an audio file from a certain position and apply fades

DESCRIPTION
Read an audio soundfile from a certain position and apply fade-in and fade-out.
Useful to add music to a scene. You may playback both mono and stereo files.
If a monaural file is passed the channel will be copied to both left and right.

SYNTAX
aleft, aright m_scene_blender Sfilename, istart, ifadein, ifadeout, ivolcurvefn

INITIALIZATION
Sfilename - Name of an audiofile containing the music or audio that you
	want to play
istart - Start time in the file in seconds
ifadein - Fade in time in seconds
ifadeout - Fade out time in seconds
ivolcurvefn - Number of an ftable holding the desired curve shape for the
	volume change (e.g. logarithmic)

PERFORMANCE
aleft, aright - Left and right outputs with fades applied

CREDITS
Author: Jeanette C.
*/

opcode m_scene_blender, aa, Siiii
	Sfile, istart, ifadein, ifadeout, ivolcurvefn xin

	; Set up some basic variables
	aleft init 0
	aright init 0
	; Read in file
	if filenchnls(Sfile) == 1 then
		aleft soundin Sfile, istart
		aright = aleft
	else
		aleft, aright soundin Sfile, istart
	endif

	; Create envelope for fades
	kindex linseg 0, ifadein, 1, p3 - (ifadein + ifadeout), 1, ifadeout, 0
	kenv table kindex, ivolcurvefn, 1

	xout aleft*kenv, aright*kenv
endop
