/*
m_scene_speaker - A very simplistc speaker emulation

DESCRIPTION
A very simplistic speaker emulation with low and high cut, rolloff at the edges
and a size parameter.
NOTE: The volume is adjusted internally, but it may still overdrive!

SYNTAX
aout m_scene_speaker ain, isize, ilowcut, ihighcut, irolloff

INITIALIZATION
isze - Size of the speaker in meters, basically the width of a cube-like speaker
ilowcut - Lowcut frequency in Hertz
ihighcut - Highcut frequency in Hertz
irolloff - Rolloff characteristic for low- and highcut.
	<1: 1 pole filters, i.e. 6dB/octave
	>=1 2pole filter, i.e. 12dB/octave with Q adjustment between 1 and 2

PERFORMANCE
ain - Input audio signal to be processed

CREDITS
Author: Jeanette C.
*/

opcode m_scene_speaker, a, aiiii
	ain, isize, ilow, ihigh, irolloff xin

	; Set up basic variables
	alpf init 0
	ahpf init 0

	; Apply low and high cut
	if irolloff < 1 then
		alpf zdf_1pole ain, ihigh, 0, 0
		ahpf zdf_1pole alpf, ilow, 1, 0
		ivol init .9
	else
		if irolloff <= 2 then
			iq = .5 + (1.5 * irolloff)
		else
			iq = 2
		endif
		alpf zdf_2pole ain, ihigh, iq, 0
		ahpf zdf_2pole alpf, ilow, iq, 1
		ivol init .7
	endif

	; apply speaker's resonance
	aout wguide1 ahpf, (340 / isize), ihigh/2, .1

	xout aout * ivol
endop
